@@ -1,6 +1,6 @@
-package Email::Sender;
+package Email::Sender 1.300036;
 # ABSTRACT: a library for sending email
-$Email::Sender::VERSION = '1.300033';
+
 use Moo::Role;
 requires 'send';
 
@@ -68,7 +68,7 @@ Email::Sender - a library for sending email
 
 =head1 VERSION
 
-version 1.300033
+version 1.300036
 
 =head1 SYNOPSIS
 
@@ -119,11 +119,11 @@ L<Email::Sender::Failure> on failure.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Alex Efros Aristotle Pagaltzis Christian Walde David Golden Steinbrunner Hans Dieter Pearcey HIROSE Masaaki Justin Hunter Karen Etheridge Kenichi Ishigaki kga Kris Matthews William Blunn
+=for stopwords Alex Efros Aristotle Pagaltzis Bernhard Graf Christian Walde David Golden Steinbrunner Hans Dieter Pearcey HIROSE Masaaki James E Keenan Justin Hunter Karen Etheridge Kenichi Ishigaki kga Kris Matthews Marc Bradshaw Stefan Hornburg (Racke) William Blunn
 
 =over 4
 
@@ -137,6 +137,10 @@ Aristotle Pagaltzis <pagaltzis@gmx.de>
 
 =item *
 
+Bernhard Graf <augensalat@gmail.com>
+
+=item *
+
 Christian Walde <walde.christian@googlemail.com>
 
 =item *
@@ -157,6 +161,10 @@ HIROSE Masaaki <hirose31@gmail.com>
 
 =item *
 
+James E Keenan <jkeenan@cpan.org>
+
+=item *
+
 Justin Hunter <justin.d.hunter@gmail.com>
 
 =item *
@@ -177,13 +185,21 @@ Kris Matthews <kris@tigerlms.com>
 
 =item *
 
+Marc Bradshaw <marc@marcbradshaw.net>
+
+=item *
+
+Stefan Hornburg (Racke) <racke@linuxia.de>
+
+=item *
+
 William Blunn <zgpmax@cpan.org>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Ricardo Signes.
+This software is copyright (c) 2021 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
