@@ -1,6 +1,6 @@
-package Email::Sender::Failure;
+package Email::Sender::Failure 1.300036;
 # ABSTRACT: a report of failure from an email sending transport
-$Email::Sender::Failure::VERSION = '1.300033';
+
 use Moo;
 extends 'Throwable::Error';
 
@@ -96,7 +96,7 @@ Email::Sender::Failure - a report of failure from an email sending transport
 
 =head1 VERSION
 
-version 1.300033
+version 1.300036
 
 =head1 ATTRIBUTES
 
@@ -140,11 +140,11 @@ be used as the C<message> of the new failure.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Ricardo Signes.
+This software is copyright (c) 2021 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
