@@ -1,6 +1,6 @@
-package Email::Sender::Success::Partial;
+package Email::Sender::Success::Partial 1.300036;
 # ABSTRACT: a report of partial success when delivering
-$Email::Sender::Success::Partial::VERSION = '1.300033';
+
 use Moo;
 extends 'Email::Sender::Success';
 
@@ -8,7 +8,7 @@ use MooX::Types::MooseLike::Base qw(InstanceOf);
 
 #pod =head1 DESCRIPTION
 #pod
-#pod These objects indicate that some deliver was accepted for some recipients and
+#pod These objects indicate that some delivery was accepted for some recipients and
 #pod not others.  The success object's C<failure> attribute will return a
 #pod L<Email::Sender::Failure::Multi> describing which parts of the delivery failed.
 #pod
@@ -37,21 +37,21 @@ Email::Sender::Success::Partial - a report of partial success when delivering
 
 =head1 VERSION
 
-version 1.300033
+version 1.300036
 
 =head1 DESCRIPTION
 
-These objects indicate that some deliver was accepted for some recipients and
+These objects indicate that some delivery was accepted for some recipients and
 not others.  The success object's C<failure> attribute will return a
 L<Email::Sender::Failure::Multi> describing which parts of the delivery failed.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Ricardo Signes.
+This software is copyright (c) 2021 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
