@@ -1,6 +1,6 @@
-package Email::Sender::Transport::DevNull;
+package Email::Sender::Transport::DevNull 1.300036;
 # ABSTRACT: happily throw away your mail
-$Email::Sender::Transport::DevNull::VERSION = '1.300033';
+
 use Moo;
 with 'Email::Sender::Transport';
 
@@ -28,7 +28,7 @@ Email::Sender::Transport::DevNull - happily throw away your mail
 
 =head1 VERSION
 
-version 1.300033
+version 1.300036
 
 =head1 DESCRIPTION
 
@@ -37,11 +37,11 @@ DevNull transport will be silently discarded.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Ricardo Signes.
+This software is copyright (c) 2021 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
