@@ -1,6 +1,6 @@
-package Email::Sender::Transport::Mbox;
+package Email::Sender::Transport::Mbox 1.300036;
 # ABSTRACT: deliver mail to an mbox on disk
-$Email::Sender::Transport::Mbox::VERSION = '1.300033';
+
 use Moo;
 with 'Email::Sender::Transport';
 
@@ -126,7 +126,7 @@ Email::Sender::Transport::Mbox - deliver mail to an mbox on disk
 
 =head1 VERSION
 
-version 1.300033
+version 1.300036
 
 =head1 DESCRIPTION
 
@@ -138,11 +138,11 @@ this may change or be configurable in the future.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Ricardo Signes.
+This software is copyright (c) 2021 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
