@@ -1,6 +1,6 @@
-package Email::Sender::Transport::Print;
+package Email::Sender::Transport::Print 1.300036;
 # ABSTRACT: print email to a filehandle (like stdout)
-$Email::Sender::Transport::Print::VERSION = '1.300033';
+
 use Moo;
 with 'Email::Sender::Transport';
 
@@ -53,7 +53,7 @@ Email::Sender::Transport::Print - print email to a filehandle (like stdout)
 
 =head1 VERSION
 
-version 1.300033
+version 1.300036
 
 =head1 DESCRIPTION
 
@@ -63,11 +63,11 @@ to as its C<fh> attribute.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Ricardo Signes.
+This software is copyright (c) 2021 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
