@@ -1,6 +1,6 @@
-package Email::Sender::Transport::SMTP;
+package Email::Sender::Transport::SMTP 1.300036;
 # ABSTRACT: send email over SMTP
-$Email::Sender::Transport::SMTP::VERSION = '1.300033';
+
 use Moo;
 
 use Email::Sender::Failure::Multi;
@@ -27,14 +27,16 @@ use utf8 (); # See below. -- rjbs, 2015-05-14
 #pod
 #pod =over 4
 #pod
-#pod =item C<host>: the name of the host to connect to; defaults to C<localhost>
+#pod =item C<hosts>: an arrayref of names of the host to try, in order; defaults to a single element array containing C<localhost>
+#pod
+#pod The attribute C<host> may be given, instead, which contains a single hostname.
 #pod
 #pod =item C<ssl>: if 'starttls', use STARTTLS; if 'ssl' (or 1), connect securely;
-#pod otherwise, no security
+#pod if 'maybestarttls', use STARTTLS if available; otherwise, no security
 #pod
 #pod =item C<ssl_options>: passed to Net::SMTP constructor for 'ssl' connections or
-#pod to starttls for 'starttls' connections; should contain extra options for
-#pod IO::Socket::SSL
+#pod to starttls for 'starttls' or 'maybestarttls' connections; should contain extra
+#pod options for IO::Socket::SSL
 #pod
 #pod =item C<port>: port to connect to; defaults to 25 for non-SSL, 465 for 'ssl',
 #pod 587 for 'starttls'
@@ -90,9 +92,10 @@ has _security => (
     return '' unless $ssl;
     $ssl = lc $ssl;
     return 'starttls' if 'starttls' eq $ssl;
+    return 'maybestarttls' if 'maybestarttls' eq $ssl;
     return 'ssl' if $ssl eq 1 or $ssl eq 'ssl';
 
-    Carp::cluck(qq{true "ssl" argument to Email::Sender::Transport::SMTP should be 'ssl' or 'startls' or '1' but got '$ssl'});
+    Carp::cluck(qq{"ssl" argument to Email::Sender::Transport::SMTP was "$ssl" rather than one of the permitted values: maybestarttls, starttls, ssl});
 
     return 1;
   },
@@ -115,7 +118,7 @@ has timeout => (is => 'ro', isa => Int, default => sub { 120 });
 
 #pod =item C<sasl_username>: the username to use for auth; optional
 #pod
-#pod =item C<sasl_password>: the password to use for auth; required if C<username> is provided
+#pod =item C<sasl_password>: the password to use for auth; required if C<sasl_username> is provided
 #pod
 #pod =item C<allow_partial_success>: if true, will send data even if some recipients were rejected; defaults to false
 #pod
@@ -182,6 +185,13 @@ sub _smtp_client {
       unless $smtp->starttls(%{ $self->ssl_options });
   }
 
+  if ($self->_security eq 'maybestarttls') {
+    if ( $smtp->supports('STARTTLS', 500, ["Command unknown: 'STARTTLS'"]) ) {
+      $self->_throw("can't STARTTLS: " . $smtp->message)
+        unless $smtp->starttls(%{ $self->ssl_options });
+    }
+  }
+
   if ($self->sasl_username) {
     $self->_throw("sasl_username but no sasl_password")
       unless defined $self->sasl_password;
@@ -284,16 +294,6 @@ sub send_email {
   while (length $msg_string) {
     my $next_hunk = substr $msg_string, 0, $hunk_size, '';
 
-    # For the need to downgrade, see
-    #   https://rt.cpan.org/Ticket/Display.html?id=104433
-    #
-    # The ||0 is there because when we've mocked Net::SMTP, there is no
-    # version.  We can't get the ->VERSION call to hit the mock, because we get
-    # the mock from ->new.  We don't want to create a new SMTP just to get the
-    # version, and we can't rely on $smtp being a Net::SMTP object.
-    # -- rjbs, 2015-08-10
-    utf8::downgrade($next_hunk) if (Net::SMTP->VERSION || 0) < 3.07;
-
     $smtp->datasend($next_hunk) or $FAULT->("error at during DATA");
   }
 
@@ -352,7 +352,7 @@ Email::Sender::Transport::SMTP - send email over SMTP
 
 =head1 VERSION
 
-version 1.300033
+version 1.300036
 
 =head1 DESCRIPTION
 
@@ -369,14 +369,16 @@ The following attributes may be passed to the constructor:
 
 =over 4
 
-=item C<host>: the name of the host to connect to; defaults to C<localhost>
+=item C<hosts>: an arrayref of names of the host to try, in order; defaults to a single element array containing C<localhost>
+
+The attribute C<host> may be given, instead, which contains a single hostname.
 
 =item C<ssl>: if 'starttls', use STARTTLS; if 'ssl' (or 1), connect securely;
-otherwise, no security
+if 'maybestarttls', use STARTTLS if available; otherwise, no security
 
 =item C<ssl_options>: passed to Net::SMTP constructor for 'ssl' connections or
-to starttls for 'starttls' connections; should contain extra options for
-IO::Socket::SSL
+to starttls for 'starttls' or 'maybestarttls' connections; should contain extra
+options for IO::Socket::SSL
 
 =item C<port>: port to connect to; defaults to 25 for non-SSL, 465 for 'ssl',
 587 for 'starttls'
@@ -385,7 +387,7 @@ IO::Socket::SSL
 
 =item C<sasl_username>: the username to use for auth; optional
 
-=item C<sasl_password>: the password to use for auth; required if C<username> is provided
+=item C<sasl_password>: the password to use for auth; required if C<sasl_username> is provided
 
 =item C<allow_partial_success>: if true, will send data even if some recipients were rejected; defaults to false
 
@@ -407,11 +409,11 @@ documentation.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Ricardo Signes.
+This software is copyright (c) 2021 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
