@@ -1,6 +1,6 @@
-package Email::Sender::Transport::Sendmail;
+package Email::Sender::Transport::Sendmail 1.300036;
 # ABSTRACT: send mail via sendmail(1)
-$Email::Sender::Transport::Sendmail::VERSION = '1.300033';
+
 use Moo;
 with 'Email::Sender::Transport';
 
@@ -112,7 +112,7 @@ Email::Sender::Transport::Sendmail - send mail via sendmail(1)
 
 =head1 VERSION
 
-version 1.300033
+version 1.300036
 
 =head2 DESCRIPTION
 
@@ -127,11 +127,11 @@ To specify the location of sendmail:
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Ricardo Signes.
+This software is copyright (c) 2021 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
