@@ -1,6 +1,6 @@
-package Email::Sender::Transport::Wrapper;
+package Email::Sender::Transport::Wrapper 1.300036;
 # ABSTRACT: a mailer to wrap a mailer for mailing mail
-$Email::Sender::Transport::Wrapper::VERSION = '1.300033';
+
 use Moo;
 with 'Email::Sender::Transport';
 
@@ -68,7 +68,7 @@ Email::Sender::Transport::Wrapper - a mailer to wrap a mailer for mailing mail
 
 =head1 VERSION
 
-version 1.300033
+version 1.300036
 
 =head1 DESCRIPTION
 
@@ -78,11 +78,11 @@ use method modifiers to create wrapping classes.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Ricardo Signes.
+This software is copyright (c) 2021 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
